==> gap-design_1.8+ds.orig.tar.xz: gap-design-1.8+ds/README.md <==
The DESIGN Package for GAP
==========================

The DESIGN package is for constructing, classifying, partitioning,
and studying block designs.

The DESIGN package is Copyright (C) Leonard H. Soicher 2003--2023.  

DESIGN is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version. For details, see 
<https://www.gnu.org/licenses/gpl.html>.

Please reference your use of the DESIGN package in a published work
as follows:

L.H. Soicher, The DESIGN package for GAP, Version 1.8, 2023,
<https://gap-packages.github.io/design>.

For questions, remarks, suggestions, and issues, please use the issue
tracker at <https://github.com/gap-packages/design/issues>.

Installing the DESIGN Package
-----------------------------

The DESIGN package is included in the standard GAP distribution. You
only need to download and install DESIGN if you need to install
the package locally or are installing an upgrade of DESIGN to
an existing installation of GAP (see the main GAP reference
section "ref:Installing a GAP Package"). If you do need to download
DESIGN, you can find an archive file for the latest release at
<https://github.com/gap-packages/design/releases>.  This archive
file can then be downloaded and unpacked in the `pkg' subdirectory of
an appropriate GAP root directory (see the main GAP reference section
"ref:GAP Root Directories").

The DESIGN package is written entirely in GAP code, and requires
no further installation.  However, the DESIGN package has complete
functionality only in an environment in which the GRAPE package is
fully installed. 

-------------------------------------------------------------------------
Leonard Soicher,
Queen Mary University of London,
February 2023

==> gap-design_1.8.2+ds.orig.tar.xz: gap-design-1.8.2+ds/README.md <==
The DESIGN 1.8.2 Package for GAP
================================

The DESIGN package is for constructing, classifying, partitioning,
and studying block designs.

The DESIGN package is Copyright (C) Leonard H. Soicher 2003--2024.  

DESIGN is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version. For details, see 
<https://www.gnu.org/licenses/gpl.html>.

Please reference your use of the DESIGN package in a published work
as follows:

L.H. Soicher, The DESIGN package for GAP, Version 1.8.2, 2024,
<https://gap-packages.github.io/design>.

For questions, remarks, suggestions, and issues, please use the issue
tracker at <https://github.com/gap-packages/design/issues>.

Installing the DESIGN Package
-----------------------------

The DESIGN package is included in the standard GAP distribution. You
only need to download and install DESIGN if you need to install
the package locally or are installing an upgrade of DESIGN to
an existing installation of GAP (see the main GAP reference
section "ref:Installing a GAP Package"). If you do need to download
DESIGN, you can find an archive file for the latest release at
<https://github.com/gap-packages/design/releases>.  This archive
file can then be downloaded and unpacked in the `pkg' subdirectory of
an appropriate GAP root directory (see the main GAP reference section
"ref:GAP Root Directories").

The DESIGN package is written entirely in GAP code, and requires
no further installation.  However, the DESIGN package has complete
functionality only in an environment in which the GRAPE package is
fully installed.
